@@ -7,112 +7,115 @@
  */
 
 /**
- * Endpoint Mask for default, which is nothing.
+ * Endpoint mask that matches nothing.
  *
  * @since 2.1.0
  */
-define('EP_NONE', 0);
+define( 'EP_NONE', 0 );
 
 /**
- * Endpoint Mask for Permalink.
+ * Endpoint mask that matches post permalinks.
  *
  * @since 2.1.0
  */
-define('EP_PERMALINK', 1);
+define( 'EP_PERMALINK', 1 );
 
 /**
- * Endpoint Mask for Attachment.
+ * Endpoint mask that matches attachment permalinks.
  *
  * @since 2.1.0
  */
-define('EP_ATTACHMENT', 2);
+define( 'EP_ATTACHMENT', 2 );
 
 /**
- * Endpoint Mask for date.
+ * Endpoint mask that matches any date archives.
  *
  * @since 2.1.0
  */
-define('EP_DATE', 4);
+define( 'EP_DATE', 4 );
 
 /**
- * Endpoint Mask for year
+ * Endpoint mask that matches yearly archives.
  *
  * @since 2.1.0
  */
-define('EP_YEAR', 8);
+define( 'EP_YEAR', 8 );
 
 /**
- * Endpoint Mask for month.
+ * Endpoint mask that matches monthly archives.
  *
  * @since 2.1.0
  */
-define('EP_MONTH', 16);
+define( 'EP_MONTH', 16 );
 
 /**
- * Endpoint Mask for day.
+ * Endpoint mask that matches daily archives.
  *
  * @since 2.1.0
  */
-define('EP_DAY', 32);
+define( 'EP_DAY', 32 );
 
 /**
- * Endpoint Mask for root.
+ * Endpoint mask that matches the site root.
  *
  * @since 2.1.0
  */
-define('EP_ROOT', 64);
+define( 'EP_ROOT', 64 );
 
 /**
- * Endpoint Mask for comments.
+ * Endpoint mask that matches comment feeds.
  *
  * @since 2.1.0
  */
-define('EP_COMMENTS', 128);
+define( 'EP_COMMENTS', 128 );
 
 /**
- * Endpoint Mask for searches.
+ * Endpoint mask that matches searches.
+ *
+ * Note that this only matches a search at a "pretty" URL such as
+ * `/search/my-search-term`, not `?s=my-search-term`.
  *
  * @since 2.1.0
  */
-define('EP_SEARCH', 256);
+define( 'EP_SEARCH', 256 );
 
 /**
- * Endpoint Mask for categories.
+ * Endpoint mask that matches category archives.
  *
  * @since 2.1.0
  */
-define('EP_CATEGORIES', 512);
+define( 'EP_CATEGORIES', 512 );
 
 /**
- * Endpoint Mask for tags.
+ * Endpoint mask that matches tag archives.
  *
  * @since 2.3.0
  */
-define('EP_TAGS', 1024);
+define( 'EP_TAGS', 1024 );
 
 /**
- * Endpoint Mask for authors.
+ * Endpoint mask that matches author archives.
  *
  * @since 2.1.0
  */
-define('EP_AUTHORS', 2048);
+define( 'EP_AUTHORS', 2048 );
 
 /**
- * Endpoint Mask for pages.
+ * Endpoint mask that matches pages.
  *
  * @since 2.1.0
  */
-define('EP_PAGES', 4096);
+define( 'EP_PAGES', 4096 );
 
 /**
- * Endpoint Mask for all archive views.
+ * Endpoint mask that matches all archive views.
  *
  * @since 3.7.0
  */
 define( 'EP_ALL_ARCHIVES', EP_DATE | EP_YEAR | EP_MONTH | EP_DAY | EP_CATEGORIES | EP_TAGS | EP_AUTHORS );
 
 /**
- * Endpoint Mask for everything.
+ * Endpoint mask that matches everything.
  *
  * @since 2.1.0
  */
@@ -127,7 +130,7 @@ define( 'EP_ALL', EP_PERMALINK | EP_ATTACHMENT | EP_ROOT | EP_COMMENTS | EP_SEAR
  * @since 2.1.0
  * @since 4.4.0 Array support was added to the `$query` parameter.
  *
- * @global WP_Rewrite $wp_rewrite WordPress Rewrite Component.
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
  *
  * @param string       $regex Regular expression to match request against.
  * @param string|array $query The corresponding query vars for this rewrite rule.
@@ -141,25 +144,26 @@ function add_rewrite_rule( $regex, $query, $after = 'bottom' ) {
 }
 
 /**
- * Add a new rewrite tag (like %postname%).
+ * Adds a new rewrite tag (like %postname%).
  *
- * The $query parameter is optional. If it is omitted you must ensure that
- * you call this on, or before, the {@see 'init'} hook. This is because $query defaults
- * to "$tag=", and for this to work a new query var has to be added.
+ * The `$query` parameter is optional. If it is omitted you must ensure that you call
+ * this on, or before, the {@see 'init'} hook. This is because `$query` defaults to
+ * `$tag=`, and for this to work a new query var has to be added.
  *
  * @since 2.1.0
  *
- * @global WP_Rewrite $wp_rewrite
- * @global WP         $wp
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
+ * @global WP         $wp         Current WordPress environment instance.
  *
  * @param string $tag   Name of the new rewrite tag.
  * @param string $regex Regular expression to substitute the tag for in rewrite rules.
  * @param string $query Optional. String to append to the rewritten query. Must end in '='. Default empty.
  */
 function add_rewrite_tag( $tag, $regex, $query = '' ) {
-	// validate the tag's name
-	if ( strlen( $tag ) < 3 || $tag[0] != '%' || $tag[ strlen($tag) - 1 ] != '%' )
+	// Validate the tag's name.
+	if ( strlen( $tag ) < 3 || '%' !== $tag[0] || '%' !== $tag[ strlen( $tag ) - 1 ] ) {
 		return;
+	}
 
 	global $wp_rewrite, $wp;
 
@@ -187,7 +191,7 @@ function remove_rewrite_tag( $tag ) {
 }
 
 /**
- * Add permalink structure.
+ * Adds a permalink structure.
  *
  * @since 3.0.0
  *
@@ -203,10 +207,12 @@ function add_permastruct( $name, $struct, $args = array() ) {
 	global $wp_rewrite;
 
 	// Back-compat for the old parameters: $with_front and $ep_mask.
-	if ( ! is_array( $args ) )
+	if ( ! is_array( $args ) ) {
 		$args = array( 'with_front' => $args );
-	if ( func_num_args() == 4 )
+	}
+	if ( func_num_args() == 4 ) {
 		$args['ep_mask'] = func_get_arg( 3 );
+	}
 
 	$wp_rewrite->add_permastruct( $name, $struct, $args );
 }
@@ -231,11 +237,11 @@ function remove_permastruct( $name ) {
 }
 
 /**
- * Add a new feed type like /atom1/.
+ * Adds a new feed type like /atom1/.
  *
  * @since 2.1.0
  *
- * @global WP_Rewrite $wp_rewrite
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
  *
  * @param string   $feedname Feed name.
  * @param callable $function Callback to run on feed display.
@@ -244,13 +250,13 @@ function remove_permastruct( $name ) {
 function add_feed( $feedname, $function ) {
 	global $wp_rewrite;
 
-	if ( ! in_array( $feedname, $wp_rewrite->feeds ) ) {
+	if ( ! in_array( $feedname, $wp_rewrite->feeds, true ) ) {
 		$wp_rewrite->feeds[] = $feedname;
 	}
 
 	$hook = 'do_feed_' . $feedname;
 
-	// Remove default function hook
+	// Remove default function hook.
 	remove_action( $hook, $hook );
 
 	add_action( $hook, $function, 10, 2 );
@@ -259,22 +265,25 @@ function add_feed( $feedname, $function ) {
 }
 
 /**
- * Remove rewrite rules and then recreate rewrite rules.
+ * Removes rewrite rules and then recreate rewrite rules.
  *
  * @since 3.0.0
  *
- * @global WP_Rewrite $wp_rewrite
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
  *
  * @param bool $hard Whether to update .htaccess (hard flush) or just update
- * 	                 rewrite_rules transient (soft flush). Default is true (hard).
+ *                   rewrite_rules option (soft flush). Default is true (hard).
  */
 function flush_rewrite_rules( $hard = true ) {
 	global $wp_rewrite;
-	$wp_rewrite->flush_rules( $hard );
+
+	if ( is_callable( array( $wp_rewrite, 'flush_rules' ) ) ) {
+		$wp_rewrite->flush_rules( $hard );
+	}
 }
 
 /**
- * Add an endpoint, like /trackback/.
+ * Adds an endpoint, like /trackback/.
  *
  * Adding an endpoint creates extra rewrite rules for each of the matching
  * places specified by the provided bitmask. For example:
@@ -298,10 +307,27 @@ function flush_rewrite_rules( $hard = true ) {
  * @since 2.1.0
  * @since 4.3.0 Added support for skipping query var registration by passing `false` to `$query_var`.
  *
- * @global WP_Rewrite $wp_rewrite
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
  *
  * @param string      $name      Name of the endpoint.
  * @param int         $places    Endpoint mask describing the places the endpoint should be added.
+ *                               Accepts a mask of:
+ *                               - `EP_ALL`
+ *                               - `EP_NONE`
+ *                               - `EP_ALL_ARCHIVES`
+ *                               - `EP_ATTACHMENT`
+ *                               - `EP_AUTHORS`
+ *                               - `EP_CATEGORIES`
+ *                               - `EP_COMMENTS`
+ *                               - `EP_DATE`
+ *                               - `EP_DAY`
+ *                               - `EP_MONTH`
+ *                               - `EP_PAGES`
+ *                               - `EP_PERMALINK`
+ *                               - `EP_ROOT`
+ *                               - `EP_SEARCH`
+ *                               - `EP_TAGS`
+ *                               - `EP_YEAR`
  * @param string|bool $query_var Name of the corresponding query variable. Pass `false` to skip registering a query_var
  *                               for this endpoint. Defaults to the value of `$name`.
  */
@@ -322,7 +348,7 @@ function add_rewrite_endpoint( $name, $places, $query_var = true ) {
  * @return string
  */
 function _wp_filter_taxonomy_base( $base ) {
-	if ( !empty( $base ) ) {
+	if ( ! empty( $base ) ) {
 		$base = preg_replace( '|^/index\.php/|', '', $base );
 		$base = trim( $base, '/' );
 	}
@@ -331,7 +357,7 @@ function _wp_filter_taxonomy_base( $base ) {
 
 
 /**
- * Resolve numeric slugs that collide with date permalinks.
+ * Resolves numeric slugs that collide with date permalinks.
  *
  * Permalinks of posts with numeric slugs can sometimes look to WP_Query::parse_query()
  * like a date archive, as when your permalink structure is `/%year%/%postname%/` and
@@ -358,7 +384,7 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 
 	// Identify the 'postname' position in the permastruct array.
 	$permastructs   = array_values( array_filter( explode( '/', get_option( 'permalink_structure' ) ) ) );
-	$postname_index = array_search( '%postname%', $permastructs );
+	$postname_index = array_search( '%postname%', $permastructs, true );
 
 	if ( false === $postname_index ) {
 		return $query_vars;
@@ -373,9 +399,9 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 	$compare = '';
 	if ( 0 === $postname_index && ( isset( $query_vars['year'] ) || isset( $query_vars['monthnum'] ) ) ) {
 		$compare = 'year';
-	} elseif ( '%year%' === $permastructs[ $postname_index - 1 ] && ( isset( $query_vars['monthnum'] ) || isset( $query_vars['day'] ) ) ) {
+	} elseif ( $postname_index && '%year%' === $permastructs[ $postname_index - 1 ] && ( isset( $query_vars['monthnum'] ) || isset( $query_vars['day'] ) ) ) {
 		$compare = 'monthnum';
-	} elseif ( '%monthnum%' === $permastructs[ $postname_index - 1 ] && isset( $query_vars['day'] ) ) {
+	} elseif ( $postname_index && '%monthnum%' === $permastructs[ $postname_index - 1 ] && isset( $query_vars['day'] ) ) {
 		$compare = 'day';
 	}
 
@@ -384,7 +410,10 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 	}
 
 	// This is the potentially clashing slug.
-	$value = $query_vars[ $compare ];
+	$value = '';
+	if ( $compare && array_key_exists( $compare, $query_vars ) ) {
+		$value = $query_vars[ $compare ];
+	}
 
 	$post = get_page_by_path( $value, OBJECT, 'post' );
 	if ( ! ( $post instanceof WP_Post ) ) {
@@ -394,12 +423,12 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 	// If the date of the post doesn't match the date specified in the URL, resolve to the date archive.
 	if ( preg_match( '/^([0-9]{4})\-([0-9]{2})/', $post->post_date, $matches ) && isset( $query_vars['year'] ) && ( 'monthnum' === $compare || 'day' === $compare ) ) {
 		// $matches[1] is the year the post was published.
-		if ( intval( $query_vars['year'] ) !== intval( $matches[1] ) ) {
+		if ( (int) $query_vars['year'] !== (int) $matches[1] ) {
 			return $query_vars;
 		}
 
 		// $matches[2] is the month the post was published.
-		if ( 'day' === $compare && isset( $query_vars['monthnum'] ) && intval( $query_vars['monthnum'] ) !== intval( $matches[2] ) ) {
+		if ( 'day' === $compare && isset( $query_vars['monthnum'] ) && (int) $query_vars['monthnum'] !== (int) $matches[2] ) {
 			return $query_vars;
 		}
 	}
@@ -414,7 +443,7 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 	} elseif ( 'monthnum' === $compare && isset( $query_vars['day'] ) ) {
 		$maybe_page = $query_vars['day'];
 	}
-	// Bug found in #11694 - 'page' was returning '/4'
+	// Bug found in #11694 - 'page' was returning '/4'.
 	$maybe_page = (int) trim( $maybe_page, '/' );
 
 	$post_page_count = substr_count( $post->post_content, '<!--nextpage-->' ) + 1;
@@ -431,7 +460,7 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 
 	// If we've gotten to this point, we have a slug/date clash. First, adjust for nextpage.
 	if ( '' !== $maybe_page ) {
-		$query_vars['page'] = intval( $maybe_page );
+		$query_vars['page'] = (int) $maybe_page;
 	}
 
 	// Next, unset autodetected date-related query vars.
@@ -447,14 +476,14 @@ function wp_resolve_numeric_slug_conflicts( $query_vars = array() ) {
 }
 
 /**
- * Examine a URL and try to determine the post ID it represents.
+ * Examines a URL and try to determine the post ID it represents.
  *
  * Checks are supposedly from the hosted site blog.
  *
  * @since 1.0.0
  *
- * @global WP_Rewrite $wp_rewrite
- * @global WP         $wp
+ * @global WP_Rewrite $wp_rewrite WordPress rewrite component.
+ * @global WP         $wp         Current WordPress environment instance.
  *
  * @param string $url Permalink to check.
  * @return int Post ID, or 0 on failure.
@@ -471,34 +500,58 @@ function url_to_postid( $url ) {
 	 */
 	$url = apply_filters( 'url_to_postid', $url );
 
-	// First, check to see if there is a 'p=N' or 'page_id=N' to match against
-	if ( preg_match('#[?&](p|page_id|attachment_id)=(\d+)#', $url, $values) )	{
-		$id = absint($values[2]);
-		if ( $id )
-			return $id;
+	$url_host = parse_url( $url, PHP_URL_HOST );
+
+	if ( is_string( $url_host ) ) {
+		$url_host = str_replace( 'www.', '', $url_host );
+	} else {
+		$url_host = '';
 	}
 
-	// Get rid of the #anchor
-	$url_split = explode('#', $url);
-	$url = $url_split[0];
+	$home_url_host = parse_url( home_url(), PHP_URL_HOST );
 
-	// Get rid of URL ?query=string
-	$url_split = explode('?', $url);
-	$url = $url_split[0];
+	if ( is_string( $home_url_host ) ) {
+		$home_url_host = str_replace( 'www.', '', $home_url_host );
+	} else {
+		$home_url_host = '';
+	}
+
+	// Bail early if the URL does not belong to this site.
+	if ( $url_host && $url_host !== $home_url_host ) {
+		return 0;
+	}
+
+	// First, check to see if there is a 'p=N' or 'page_id=N' to match against.
+	if ( preg_match( '#[?&](p|page_id|attachment_id)=(\d+)#', $url, $values ) ) {
+		$id = absint( $values[2] );
+		if ( $id ) {
+			return $id;
+		}
+	}
+
+	// Get rid of the #anchor.
+	$url_split = explode( '#', $url );
+	$url       = $url_split[0];
+
+	// Get rid of URL ?query=string.
+	$url_split = explode( '?', $url );
+	$url       = $url_split[0];
 
 	// Set the correct URL scheme.
 	$scheme = parse_url( home_url(), PHP_URL_SCHEME );
-	$url = set_url_scheme( $url, $scheme );
+	$url    = set_url_scheme( $url, $scheme );
 
-	// Add 'www.' if it is absent and should be there
-	if ( false !== strpos(home_url(), '://www.') && false === strpos($url, '://www.') )
-		$url = str_replace('://', '://www.', $url);
+	// Add 'www.' if it is absent and should be there.
+	if ( false !== strpos( home_url(), '://www.' ) && false === strpos( $url, '://www.' ) ) {
+		$url = str_replace( '://', '://www.', $url );
+	}
 
-	// Strip 'www.' if it is present and shouldn't be
-	if ( false === strpos(home_url(), '://www.') )
-		$url = str_replace('://www.', '://', $url);
+	// Strip 'www.' if it is present and shouldn't be.
+	if ( false === strpos( home_url(), '://www.' ) ) {
+		$url = str_replace( '://www.', '://', $url );
+	}
 
-	if ( trim( $url, '/' ) === home_url() && 'page' == get_option( 'show_on_front' ) ) {
+	if ( trim( $url, '/' ) === home_url() && 'page' === get_option( 'show_on_front' ) ) {
 		$page_on_front = get_option( 'page_on_front' );
 
 		if ( $page_on_front && get_post( $page_on_front ) instanceof WP_Post ) {
@@ -506,48 +559,52 @@ function url_to_postid( $url ) {
 		}
 	}
 
-	// Check to see if we are using rewrite rules
+	// Check to see if we are using rewrite rules.
 	$rewrite = $wp_rewrite->wp_rewrite_rules();
 
-	// Not using rewrite rules, and 'p=N' and 'page_id=N' methods failed, so we're out of options
-	if ( empty($rewrite) )
+	// Not using rewrite rules, and 'p=N' and 'page_id=N' methods failed, so we're out of options.
+	if ( empty( $rewrite ) ) {
 		return 0;
-
-	// Strip 'index.php/' if we're not using path info permalinks
-	if ( !$wp_rewrite->using_index_permalinks() )
-		$url = str_replace( $wp_rewrite->index . '/', '', $url );
-
-	if ( false !== strpos( trailingslashit( $url ), home_url( '/' ) ) ) {
-		// Chop off http://domain.com/[path]
-		$url = str_replace(home_url(), '', $url);
-	} else {
-		// Chop off /path/to/blog
-		$home_path = parse_url( home_url( '/' ) );
-		$home_path = isset( $home_path['path'] ) ? $home_path['path'] : '' ;
-		$url = preg_replace( sprintf( '#^%s#', preg_quote( $home_path ) ), '', trailingslashit( $url ) );
 	}
 
-	// Trim leading and lagging slashes
-	$url = trim($url, '/');
+	// Strip 'index.php/' if we're not using path info permalinks.
+	if ( ! $wp_rewrite->using_index_permalinks() ) {
+		$url = str_replace( $wp_rewrite->index . '/', '', $url );
+	}
 
-	$request = $url;
+	if ( false !== strpos( trailingslashit( $url ), home_url( '/' ) ) ) {
+		// Chop off http://domain.com/[path].
+		$url = str_replace( home_url(), '', $url );
+	} else {
+		// Chop off /path/to/blog.
+		$home_path = parse_url( home_url( '/' ) );
+		$home_path = isset( $home_path['path'] ) ? $home_path['path'] : '';
+		$url       = preg_replace( sprintf( '#^%s#', preg_quote( $home_path ) ), '', trailingslashit( $url ) );
+	}
+
+	// Trim leading and lagging slashes.
+	$url = trim( $url, '/' );
+
+	$request              = $url;
 	$post_type_query_vars = array();
 
-	foreach ( get_post_types( array() , 'objects' ) as $post_type => $t ) {
-		if ( ! empty( $t->query_var ) )
+	foreach ( get_post_types( array(), 'objects' ) as $post_type => $t ) {
+		if ( ! empty( $t->query_var ) ) {
 			$post_type_query_vars[ $t->query_var ] = $post_type;
+		}
 	}
 
 	// Look for matches.
 	$request_match = $request;
-	foreach ( (array)$rewrite as $match => $query) {
+	foreach ( (array) $rewrite as $match => $query ) {
 
-		// If the requesting file is the anchor of the match, prepend it
-		// to the path info.
-		if ( !empty($url) && ($url != $request) && (strpos($match, $url) === 0) )
+		// If the requesting file is the anchor of the match,
+		// prepend it to the path info.
+		if ( ! empty( $url ) && ( $url != $request ) && ( strpos( $match, $url ) === 0 ) ) {
 			$request_match = $url . '/' . $request;
+		}
 
-		if ( preg_match("#^$match#", $request_match, $matches) ) {
+		if ( preg_match( "#^$match#", $request_match, $matches ) ) {
 
 			if ( $wp_rewrite->use_verbose_page_rules && preg_match( '/pagename=\$matches\[([0-9]+)\]/', $query, $varmatch ) ) {
 				// This is a verbose page match, let's check to be sure about it.
@@ -565,21 +622,21 @@ function url_to_postid( $url ) {
 
 			// Got a match.
 			// Trim the query of everything up to the '?'.
-			$query = preg_replace("!^.+\?!", '', $query);
+			$query = preg_replace( '!^.+\?!', '', $query );
 
 			// Substitute the substring matches into the query.
-			$query = addslashes(WP_MatchesMapRegex::apply($query, $matches));
+			$query = addslashes( WP_MatchesMapRegex::apply( $query, $matches ) );
 
-			// Filter out non-public query vars
+			// Filter out non-public query vars.
 			global $wp;
 			parse_str( $query, $query_vars );
 			$query = array();
 			foreach ( (array) $query_vars as $key => $value ) {
-				if ( in_array( $key, $wp->public_query_vars ) ){
-					$query[$key] = $value;
-					if ( isset( $post_type_query_vars[$key] ) ) {
-						$query['post_type'] = $post_type_query_vars[$key];
-						$query['name'] = $value;
+				if ( in_array( (string) $key, $wp->public_query_vars, true ) ) {
+					$query[ $key ] = $value;
+					if ( isset( $post_type_query_vars[ $key ] ) ) {
+						$query['post_type'] = $post_type_query_vars[ $key ];
+						$query['name']      = $value;
 					}
 				}
 			}
@@ -587,12 +644,13 @@ function url_to_postid( $url ) {
 			// Resolve conflicts between posts with numeric slugs and date archive queries.
 			$query = wp_resolve_numeric_slug_conflicts( $query );
 
-			// Do the query
+			// Do the query.
 			$query = new WP_Query( $query );
-			if ( ! empty( $query->posts ) && $query->is_singular )
+			if ( ! empty( $query->posts ) && $query->is_singular ) {
 				return $query->post->ID;
-			else
+			} else {
 				return 0;
+			}
 		}
 	}
 	return 0;
